..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============

Invenio-Records can be installed from PyPI. Several installation options are
possible, for example to use SQLite database backend::

  pip install invenio-records[sqlite]

The other installation [options] include:

  ``access``
      for access control capabilities;
  ``docs``
      for documentation building dependencies;
  ``mysql``
      to use MySQL database backend;
  ``postgresql``
      to use PostgreSQL database backend;
  ``sqlite``
      to use SQLite database backend;
  ``admin``
      for Flask administration interfaces;
  ``tests``
      for test dependencies.
